==> ecs-1.60.0-sources.jar: software/amazon/awscdk/services/ecs/BuiltInAttributes.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The built-in container instance attributes.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:32.956Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.BuiltInAttributes")
public class BuiltInAttributes extends software.amazon.jsii.JsiiObject {

    protected BuiltInAttributes(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected BuiltInAttributes(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AMI_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "AMI_ID", java.lang.String.class);
        AVAILABILITY_ZONE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "AVAILABILITY_ZONE", java.lang.String.class);
        INSTANCE_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "INSTANCE_ID", java.lang.String.class);
        INSTANCE_TYPE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "INSTANCE_TYPE", java.lang.String.class);
        OS_TYPE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "OS_TYPE", java.lang.String.class);
    }

    public BuiltInAttributes() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * The AMI id the instance is using.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String AMI_ID;

    /**
     * The AvailabilityZone where the instance is running in.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String AVAILABILITY_ZONE;

    /**
     * The id of the instance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String INSTANCE_ID;

    /**
     * The EC2 instance type.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String INSTANCE_TYPE;

    /**
     * The operating system of the instance.
     * <p>
     * Either 'linux' or 'windows'.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String OS_TYPE;
}

==> ecs-1.100.0-sources.jar: software/amazon/awscdk/services/ecs/BuiltInAttributes.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The built-in container instance attributes.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:41.759Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.BuiltInAttributes")
public class BuiltInAttributes extends software.amazon.jsii.JsiiObject {

    protected BuiltInAttributes(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected BuiltInAttributes(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        AMI_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "AMI_ID", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        AVAILABILITY_ZONE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "AVAILABILITY_ZONE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        INSTANCE_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "INSTANCE_ID", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        INSTANCE_TYPE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "INSTANCE_TYPE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        OS_TYPE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.ecs.BuiltInAttributes.class, "OS_TYPE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public BuiltInAttributes() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * The AMI id the instance is using.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String AMI_ID;

    /**
     * The AvailabilityZone where the instance is running in.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String AVAILABILITY_ZONE;

    /**
     * The id of the instance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String INSTANCE_ID;

    /**
     * The EC2 instance type.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String INSTANCE_TYPE;

    /**
     * The operating system of the instance.
     * <p>
     * Either 'linux' or 'windows'.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String OS_TYPE;
}
